SystemOrganization addCategory: #ConfigurationOfDeveloperWorkspace!

Object subclass: #ConfigurationOfDeveloperWorkspace
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDeveloperWorkspace'!

!ConfigurationOfDeveloperWorkspace class methodsFor: 'development support' stamp: 'tbn 2/28/2013 08:58'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'private' stamp: 'tbn 2/28/2013 08:58'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'private' stamp: 'tbn 2/28/2013 08:58'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'private' stamp: 'tbn 2/28/2013 08:58'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'metacello tool support' stamp: 'tbn 2/28/2013 08:58'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'loading' stamp: 'tbn 2/28/2013 08:58'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'loading' stamp: 'tbn 2/28/2013 08:58'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'loading' stamp: 'tbn 2/28/2013 08:58'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'accessing' stamp: 'tbn 2/28/2013 08:58'!
project

	^self new project! !

!ConfigurationOfDeveloperWorkspace class methodsFor: 'development support' stamp: 'tbn 2/28/2013 08:58'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'baselines' stamp: 'TorstenBergmann 9/15/2013 21:57'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'pharo' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/TorstenBergmann/PharoGoodies/main'.
		spec package: 'DeveloperWorkspace'
			with: [ spec requires: #('SimplePersistence' 'ScriptManager' 'Pomodoro' 'Pastell' 'PharoOnlineHelp' 'VistaCursors') ].
		spec group: 'default' with: #('DeveloperWorkspace' ).
		
	"Simple persistence"
	  spec
			project: 'SimplePersistence' with: [
				spec
					className: 'ConfigurationOfSimplePersistence';
					file: 'ConfigurationOfSimplePersistence';
					version: '2.0-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].
	 "Script Manager"
	  spec
			project: 'ScriptManager' with: [
				spec
					className: 'ConfigurationOfScriptManager';
					file: 'ConfigurationOfScriptManager';
					version: '1.1-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].
				
	 "Pomodoro"
	  spec
			project: 'Pomodoro' with: [
				spec
					className: 'ConfigurationOfPomodoro';
					file: 'ConfigurationOfPomodoro';
					version: '1.0-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].				
								
 	 "Pastell and XML support"		
	 spec
			project: 'Pastell' with: [
				spec
					className: 'ConfigurationOfPastell';
					file: 'ConfigurationOfPastell';
					version: '1.0.2-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].	
	"Online Help"							
	spec
			project: 'PharoOnlineHelp' with: [
				spec
					className: 'ConfigurationOfPharoOnlineHelp';
					file: 'ConfigurationOfPharoOnlineHelp';
					version: '1.0-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].
	"Vista Cursor"
	spec
			project: 'VistaCursors' with: [
				spec
					className: 'ConfigurationOfVistaCursors';
					file: 'ConfigurationOfVistaCursors';
					version: '1.0-baseline';
					repository: 'http://ss3.gemstone.com/ss/MetaRepoForPharo20' ].																						
    ]
	
	 
! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'accessing' stamp: 'tbn 2/28/2013 08:58'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'symbolic versions' stamp: 'tbn 2/28/2013 08:58'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'doits' stamp: 'tbn 3/13/2013 12:29'!
postloadForCore: loader package: packageSpec

	|form| 
      Display fullscreen: true.
      form := ZnEasy getJpeg: 'http://ubuntu.ecchi.ca/wallpapers/10.04//Maraetaibeforesunrise.jpg'. 
      World backgroundImage: form layout: #scaled.
	self showWelcome! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'accessing' stamp: 'tbn 2/28/2013 08:58'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'doits' stamp: 'tbn 3/13/2013 12:29'!
showWelcome

	|text|
	text := TextMorph new 
		newContents: 'Welcome to Pharo Developer Workspace';
		textColor: Color white;
		extent: 180@50;
		yourself.

	RectangleMorph new  
	 cornerStyle: #rounded;
	 extent: 200@100;
	 borderWidth: 2;
	 borderColor: Color gray;
	borderStyle: BorderStyle thinGray;
	 color: (Color black alpha: 0.8);
 
 	addMorphCentered: text;
 	openInWorld;
	position: 100@100
! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'symbolic versions' stamp: 'tbn 2/28/2013 08:59'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfDeveloperWorkspace methodsFor: 'versions' stamp: 'TorstenBergmann 9/15/2013 21:54'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'tbn'.
		spec timestamp: '2/28/2013 08:58'.
		spec package: 'DeveloperWorkspace' with: 'DeveloperWorkspace-tbn.1'. 
		"postload"
		spec postLoadDoIt: #postloadForCore:package:.
		"projects"
		spec project: 'SimplePersistence' with: '2.0.1'.
		spec project: 'ScriptManager' with: '1.6'.
		spec project: 'Pomodoro' with: '1.5'.
		spec project: 'Pastell' with: '1.3'.
		spec project: 'PharoOnlineHelp' with: '1.3'.
		spec project: 'VistaCursors' with: '1.0'.	
		].

! !
